/**********************************************************************
 
	Copyright (C) 2003 Hirohisa MORI <joshua@nichibun.ac.jp>
 
	This program is free software; you can redistribute it 
	and/or modify it under the terms of the GLOBALBASE 
	Library General Public License (G-LGPL) as published by 

	http://www.globalbase.org/
 
	This program is distributed in the hope that it will be 
	useful, but WITHOUT ANY WARRANTY; without even the 
	implied warranty of MERCHANTABILITY or FITNESS FOR A 
	PARTICULAR PURPOSE.

**********************************************************************/

#ifndef ___MSEQUENCE_H___
#define ___MSEQUENCE_H___

#include "thread.h"

#define MS_INFO_NUM 100

typedef struct ms_info
{
	struct ms_info *	next;
	int 			(*func)();
	void * 			arg;
	char 			str[256];
	int 			result;
} MS_INFO;

void init_msequence();
void ms_loop();
void ms_loop_proc();
int ms_do(int (*func)(void*), void * arg,int,const char str[]);
int get_userinterface_tid();
//void er_panic(char*);

#endif

